==> adapter-vue-4.2.3.tgz: package/bundles/index.esm.js <==
import { makeError, VElement, VTextNode, Adapter } from '@textbus/core';
import { ref, h, getCurrentInstance, onMounted, onUpdated, onUnmounted } from 'vue';
import { DomAdapter } from '@textbus/platform-browser';
import { ReflectiveInjector } from '@viewfly/core';

const adapterError = makeError('VueAdapter');
class VueAdapter extends DomAdapter {
    constructor(components, mount) {
        super({
            createCompositionNode: (compositionState, updateNativeCompositionNode) => {
                return new VElement('span', {
                    style: {
                        textDecoration: 'underline'
                    },
                    ref: updateNativeCompositionNode
                }, [
                    new VTextNode(compositionState.text)
                ]);
            },
            getParentNode(node) {
                return node.parentNode;
            },
            getChildNodes(parentElement) {
                return Array.from(parentElement.childNodes);
            },
            isNativeElementNode(node) {
                return node instanceof Element;
            },
            getChildByIndex(parentElement, index) {
                return parentElement.childNodes[index];
            },
            getAndUpdateSlotRootNativeElement(vElement, update) {
                const currentRef = vElement.attrs.get('ref');
                if (currentRef) {
                    vElement.attrs.set('ref', (v) => {
                        update(v);
                        if (typeof currentRef === 'function') {
                            currentRef(v);
                        }
                        else if (!currentRef.value) {
                            currentRef.value = v;
                        }
                    });
                }
                else {
                    vElement.attrs.set('ref', update);
                }
            },
            componentRender: (component) => {
                const comp = this.components[component.name] || this.components['*'];
                if (comp) {
                    let rootRef = this.componentRefs.get(component);
                    if (!rootRef) {
                        rootRef = ref();
                        this.componentRefs.set(component, rootRef);
                    }
                    return h(comp, {
                        component,
                        rootRef,
                        key: component.id
                    });
                }
                throw adapterError(`cannot found view component \`${component.name}\`!`);
            },
            vElementToViewElement(vNode, children) {
                const props = Object.assign({}, (Array.from(vNode.attrs).reduce((a, b) => {
                    a[b[0]] = b[1];
                    return a;
                }, {})));
                if (vNode.classes.size) {
                    props.class = Array.from(vNode.classes).join(' ');
                }
                if (vNode.styles) {
                    props.style = Array.from(vNode.styles).reduce((a, b) => {
                        a[b[0]] = b[1];
                        return a;
                    }, {});
                }
                return h(vNode.tagName, props, ...children);
            }
        }, mount);
        // private compositionRef = ref<Element>()
        this.componentRefs = new WeakMap();
        this.components = {};
        // watchEffect(() => {
        //   this.compositionNode = this.compositionRef.value || null
        // })
        Object.keys(components).forEach(key => {
            const vueComponent = components[key];
            const setup = vueComponent.setup;
            const self = this;
            vueComponent.setup = function (props, context, ...args) {
                const component = props.component;
                const vueInstance = getCurrentInstance();
                const sub = component.changeMarker.onChange.subscribe(() => {
                    if (component.changeMarker.dirty) {
                        vueInstance.proxy.$forceUpdate();
                    }
                });
                onMounted(() => {
                    if (props.rootRef.value) {
                        self.componentRootElementCaches.set(component, props.rootRef.value);
                    }
                    else {
                        self.componentRootElementCaches.remove(component);
                    }
                });
                onUpdated(() => {
                    var _a;
                    component.changeMarker.rendered();
                    self.onViewUpdated.next();
                    if (!(((_a = self.componentRefs.get(component)) === null || _a === void 0 ? void 0 : _a.value) instanceof Element)) {
                        // eslint-disable-next-line max-len
                        throw adapterError(`Component \`${component.name}\` is not bound to rootRef, you must bind rootRef to the root element node of the component view.`);
                    }
                });
                onUnmounted(() => {
                    sub.unsubscribe();
                });
                return setup(props, context, ...args);
            };
            this.components[key] = vueComponent;
        });
    }
    render(rootComponent, injector) {
        const childrenInjector = new ReflectiveInjector(injector, [{
                provide: Adapter,
                useValue: this
            }, {
                provide: DomAdapter,
                useValue: this,
            }, {
                provide: VueAdapter,
                useValue: this
            }]);
        return super.render(rootComponent, childrenInjector);
    }
    copy() {
        document.execCommand('copy');
    }
}

export { VueAdapter };

==> adapter-vue-4.3.4.tgz: package/bundles/index.esm.js <==
import { makeError, VElement, VTextNode, Adapter } from '@textbus/core';
import { ref, h, getCurrentInstance, onMounted, onUpdated, onUnmounted } from 'vue';
import { DomAdapter } from '@textbus/platform-browser';
import { ReflectiveInjector } from '@viewfly/core';
import { merge } from '@tanbo/stream';

const adapterError = makeError('VueAdapter');
class VueAdapter extends DomAdapter {
    constructor(components, mount) {
        super({
            createCompositionNode: (compositionState, updateNativeCompositionNode) => {
                return new VElement('span', {
                    style: {
                        textDecoration: 'underline'
                    },
                    ref: updateNativeCompositionNode
                }, [
                    new VTextNode(compositionState.text)
                ]);
            },
            getParentNode(node) {
                return node.parentNode;
            },
            getChildNodes(parentElement) {
                return Array.from(parentElement.childNodes);
            },
            isNativeElementNode(node) {
                return node instanceof Element;
            },
            getChildByIndex(parentElement, index) {
                return parentElement.childNodes[index];
            },
            getAndUpdateSlotRootNativeElement(vElement, update) {
                const currentRef = vElement.attrs.get('ref');
                if (currentRef) {
                    vElement.attrs.set('ref', (v) => {
                        update(v);
                        if (typeof currentRef === 'function') {
                            currentRef(v);
                        }
                        else if (!currentRef.value) {
                            currentRef.value = v;
                        }
                    });
                }
                else {
                    vElement.attrs.set('ref', update);
                }
            },
            componentRender: (component) => {
                const comp = this.components[component.name] || this.components['*'];
                if (comp) {
                    let rootRef = this.componentRefs.get(component);
                    if (!rootRef) {
                        rootRef = ref();
                        this.componentRefs.set(component, rootRef);
                    }
                    return h(comp, {
                        component,
                        rootRef,
                        key: component.id
                    });
                }
                throw adapterError(`cannot found view component \`${component.name}\`!`);
            },
            vElementToViewElement(vNode, children) {
                const props = Object.assign({}, (Array.from(vNode.attrs).reduce((a, b) => {
                    a[b[0]] = b[1];
                    return a;
                }, {})));
                if (vNode.classes.size) {
                    props.class = Array.from(vNode.classes).join(' ');
                }
                if (vNode.styles) {
                    props.style = Array.from(vNode.styles).reduce((a, b) => {
                        a[b[0]] = b[1];
                        return a;
                    }, {});
                }
                return h(vNode.tagName, props, ...children);
            }
        }, mount);
        // private compositionRef = ref<Element>()
        this.componentRefs = new WeakMap();
        this.components = {};
        // watchEffect(() => {
        //   this.compositionNode = this.compositionRef.value || null
        // })
        Object.keys(components).forEach(key => {
            const vueComponent = components[key];
            const setup = vueComponent.setup;
            const self = this;
            vueComponent.setup = function (props, context, ...args) {
                const component = props.component;
                const vueInstance = getCurrentInstance();
                const sub = merge(component.changeMarker.onChange, component.changeMarker.onForceChange).subscribe(() => {
                    if (component.changeMarker.dirty) {
                        vueInstance.proxy.$forceUpdate();
                    }
                });
                onMounted(() => {
                    if (props.rootRef.value) {
                        self.componentRootElementCaches.set(component, props.rootRef.value);
                    }
                    else {
                        self.componentRootElementCaches.remove(component);
                    }
                });
                onUpdated(() => {
                    var _a;
                    component.changeMarker.rendered();
                    self.onViewUpdated.next();
                    if (!(((_a = self.componentRefs.get(component)) === null || _a === void 0 ? void 0 : _a.value) instanceof Element)) {
                        // eslint-disable-next-line max-len
                        throw adapterError(`Component \`${component.name}\` is not bound to rootRef, you must bind rootRef to the root element node of the component view.`);
                    }
                });
                onUnmounted(() => {
                    sub.unsubscribe();
                });
                return setup(props, context, ...args);
            };
            this.components[key] = vueComponent;
        });
    }
    render(rootComponent, injector) {
        const childrenInjector = new ReflectiveInjector(injector, [{
                provide: Adapter,
                useValue: this
            }, {
                provide: DomAdapter,
                useValue: this,
            }, {
                provide: VueAdapter,
                useValue: this
            }]);
        return super.render(rootComponent, childrenInjector);
    }
    copy() {
        document.execCommand('copy');
    }
}

export { VueAdapter };
